==> openjph-doc-0.24.2-1-any.pkg.tar.zst: usr/share/doc/openjph/annotated_dup.js <==
var annotated_dup =
[
    [ "ojph", "namespaceojph.html", [
      [ "local", "namespaceojph_1_1local.html", [
        [ "bibo_gains", "classojph_1_1local_1_1bibo__gains.html", "classojph_1_1local_1_1bibo__gains" ],
        [ "bit_read_buf", "structojph_1_1local_1_1bit__read__buf.html", "structojph_1_1local_1_1bit__read__buf" ],
        [ "bit_write_buf", "structojph_1_1local_1_1bit__write__buf.html", "structojph_1_1local_1_1bit__write__buf" ],
        [ "cod_SGcod", "structojph_1_1local_1_1cod__SGcod.html", "structojph_1_1local_1_1cod__SGcod" ],
        [ "cod_SPcod", "structojph_1_1local_1_1cod__SPcod.html", "structojph_1_1local_1_1cod__SPcod" ],
        [ "codeblock", "classojph_1_1local_1_1codeblock.html", "classojph_1_1local_1_1codeblock" ],
        [ "codeblock_fun", "structojph_1_1local_1_1codeblock__fun.html", "structojph_1_1local_1_1codeblock__fun" ],
        [ "coded_cb_header", "structojph_1_1local_1_1coded__cb__header.html", "structojph_1_1local_1_1coded__cb__header" ],
        [ "codestream", "classojph_1_1local_1_1codestream.html", "classojph_1_1local_1_1codestream" ],
        [ "CT_CNST", "structojph_1_1local_1_1CT__CNST.html", "structojph_1_1local_1_1CT__CNST" ],
        [ "dec_mel_st", "structojph_1_1local_1_1dec__mel__st.html", "structojph_1_1local_1_1dec__mel__st" ],
        [ "frwd_struct", "structojph_1_1local_1_1frwd__struct.html", "structojph_1_1local_1_1frwd__struct" ],
        [ "frwd_struct32", "structojph_1_1local_1_1frwd__struct32.html", "structojph_1_1local_1_1frwd__struct32" ],
        [ "frwd_struct64", "structojph_1_1local_1_1frwd__struct64.html", "structojph_1_1local_1_1frwd__struct64" ],
        [ "lifting_step", "unionojph_1_1local_1_1lifting__step.html", "unionojph_1_1local_1_1lifting__step" ],
        [ "mel_struct", "structojph_1_1local_1_1mel__struct.html", "structojph_1_1local_1_1mel__struct" ],
        [ "ms_struct", "structojph_1_1local_1_1ms__struct.html", "structojph_1_1local_1_1ms__struct" ],
        [ "param_atk", "structojph_1_1local_1_1param__atk.html", "structojph_1_1local_1_1param__atk" ],
        [ "param_cap", "structojph_1_1local_1_1param__cap.html", "structojph_1_1local_1_1param__cap" ],
        [ "param_cod", "structojph_1_1local_1_1param__cod.html", "structojph_1_1local_1_1param__cod" ],
        [ "param_dfs", "structojph_1_1local_1_1param__dfs.html", "structojph_1_1local_1_1param__dfs" ],
        [ "param_nlt", "structojph_1_1local_1_1param__nlt.html", "structojph_1_1local_1_1param__nlt" ],
        [ "param_qcd", "structojph_1_1local_1_1param__qcd.html", "structojph_1_1local_1_1param__qcd" ],
        [ "param_siz", "structojph_1_1local_1_1param__siz.html", "structojph_1_1local_1_1param__siz" ],
        [ "param_sot", "structojph_1_1local_1_1param__sot.html", "structojph_1_1local_1_1param__sot" ],
        [ "param_tlm", "structojph_1_1local_1_1param__tlm.html", "structojph_1_1local_1_1param__tlm" ],
        [ "precinct", "structojph_1_1local_1_1precinct.html", "structojph_1_1local_1_1precinct" ],
        [ "resolution", "classojph_1_1local_1_1resolution.html", "classojph_1_1local_1_1resolution" ],
        [ "rev_struct", "structojph_1_1local_1_1rev__struct.html", "structojph_1_1local_1_1rev__struct" ],
        [ "siz_comp_info", "structojph_1_1local_1_1siz__comp__info.html", "structojph_1_1local_1_1siz__comp__info" ],
        [ "sqrt_energy_gains", "classojph_1_1local_1_1sqrt__energy__gains.html", "classojph_1_1local_1_1sqrt__energy__gains" ],
        [ "subband", "classojph_1_1local_1_1subband.html", "classojph_1_1local_1_1subband" ],
        [ "tag_tree", "structojph_1_1local_1_1tag__tree.html", "structojph_1_1local_1_1tag__tree" ],
        [ "tile", "classojph_1_1local_1_1tile.html", "classojph_1_1local_1_1tile" ],
        [ "tile_comp", "classojph_1_1local_1_1tile__comp.html", "classojph_1_1local_1_1tile__comp" ],
        [ "uvlc_tbl_struct", "structojph_1_1local_1_1uvlc__tbl__struct.html", "structojph_1_1local_1_1uvlc__tbl__struct" ],
        [ "vlc_struct", "structojph_1_1local_1_1vlc__struct.html", "structojph_1_1local_1_1vlc__struct" ]
      ] ],
      [ "net", "namespaceojph_1_1net.html", [
        [ "socket", "classojph_1_1net_1_1socket.html", "classojph_1_1net_1_1socket" ],
        [ "socket_manager", "classojph_1_1net_1_1socket__manager.html", "classojph_1_1net_1_1socket__manager" ]
      ] ],
      [ "stex", "namespaceojph_1_1stex.html", [
        [ "frames_handler", "classojph_1_1stex_1_1frames__handler.html", "classojph_1_1stex_1_1frames__handler" ],
        [ "j2k_frame_storer", "structojph_1_1stex_1_1j2k__frame__storer.html", "structojph_1_1stex_1_1j2k__frame__storer" ],
        [ "packets_handler", "classojph_1_1stex_1_1packets__handler.html", "classojph_1_1stex_1_1packets__handler" ],
        [ "rtp_packet", "structojph_1_1stex_1_1rtp__packet.html", "structojph_1_1stex_1_1rtp__packet" ],
        [ "stex_file", "structojph_1_1stex_1_1stex__file.html", "structojph_1_1stex_1_1stex__file" ]
      ] ],
      [ "thds", "namespaceojph_1_1thds.html", [
        [ "thread_pool", "classojph_1_1thds_1_1thread__pool.html", "classojph_1_1thds_1_1thread__pool" ],
        [ "worker_thread_base", "classojph_1_1thds_1_1worker__thread__base.html", "classojph_1_1thds_1_1worker__thread__base" ]
      ] ],
      [ "argument", "classojph_1_1argument.html", "classojph_1_1argument" ],
      [ "cli_interpreter", "classojph_1_1cli__interpreter.html", "classojph_1_1cli__interpreter" ],
      [ "coded_lists", "structojph_1_1coded__lists.html", "structojph_1_1coded__lists" ],
      [ "codestream", "classojph_1_1codestream.html", "classojph_1_1codestream" ],
      [ "comment_exchange", "classojph_1_1comment__exchange.html", "classojph_1_1comment__exchange" ],
      [ "dpx_in", "classojph_1_1dpx__in.html", "classojph_1_1dpx__in" ],
      [ "image_in_base", "classojph_1_1image__in__base.html", "classojph_1_1image__in__base" ],
      [ "image_out_base", "classojph_1_1image__out__base.html", "classojph_1_1image__out__base" ],
      [ "infile_base", "classojph_1_1infile__base.html", "classojph_1_1infile__base" ],
      [ "j2c_infile", "classojph_1_1j2c__infile.html", "classojph_1_1j2c__infile" ],
      [ "j2c_outfile", "classojph_1_1j2c__outfile.html", "classojph_1_1j2c__outfile" ],
      [ "lifting_buf", "structojph_1_1lifting__buf.html", "structojph_1_1lifting__buf" ],
      [ "line_buf", "classojph_1_1line__buf.html", "classojph_1_1line__buf" ],
      [ "mem_elastic_allocator", "classojph_1_1mem__elastic__allocator.html", "classojph_1_1mem__elastic__allocator" ],
      [ "mem_fixed_allocator", "classojph_1_1mem__fixed__allocator.html", "classojph_1_1mem__fixed__allocator" ],
      [ "mem_infile", "classojph_1_1mem__infile.html", "classojph_1_1mem__infile" ],
      [ "mem_outfile", "classojph_1_1mem__outfile.html", "classojph_1_1mem__outfile" ],
      [ "message_base", "classojph_1_1message__base.html", "classojph_1_1message__base" ],
      [ "message_error", "classojph_1_1message__error.html", "classojph_1_1message__error" ],
      [ "message_info", "classojph_1_1message__info.html", "classojph_1_1message__info" ],
      [ "message_warning", "classojph_1_1message__warning.html", "classojph_1_1message__warning" ],
      [ "outfile_base", "classojph_1_1outfile__base.html", "classojph_1_1outfile__base" ],
      [ "param_coc", "classojph_1_1param__coc.html", "classojph_1_1param__coc" ],
      [ "param_cod", "classojph_1_1param__cod.html", "classojph_1_1param__cod" ],
      [ "param_nlt", "classojph_1_1param__nlt.html", "classojph_1_1param__nlt" ],
      [ "param_qcd", "classojph_1_1param__qcd.html", "classojph_1_1param__qcd" ],
      [ "param_siz", "classojph_1_1param__siz.html", "classojph_1_1param__siz" ],
      [ "pfm_in", "classojph_1_1pfm__in.html", "classojph_1_1pfm__in" ],
      [ "pfm_out", "classojph_1_1pfm__out.html", "classojph_1_1pfm__out" ],
      [ "point", "structojph_1_1point.html", "structojph_1_1point" ],
      [ "ppm_in", "classojph_1_1ppm__in.html", "classojph_1_1ppm__in" ],
      [ "ppm_out", "classojph_1_1ppm__out.html", "classojph_1_1ppm__out" ],
      [ "raw_in", "classojph_1_1raw__in.html", "classojph_1_1raw__in" ],
      [ "raw_out", "classojph_1_1raw__out.html", "classojph_1_1raw__out" ],
      [ "rect", "structojph_1_1rect.html", "structojph_1_1rect" ],
      [ "size", "structojph_1_1size.html", "structojph_1_1size" ],
      [ "yuv_in", "classojph_1_1yuv__in.html", "classojph_1_1yuv__in" ],
      [ "yuv_out", "classojph_1_1yuv__out.html", "classojph_1_1yuv__out" ]
    ] ],
    [ "img_info", "structimg__info.html", "structimg__info" ],
    [ "j2k_struct", "structj2k__struct.html", "structj2k__struct" ],
    [ "point_interpreter", "structpoint__interpreter.html", "structpoint__interpreter" ],
    [ "point_list_interpreter", "structpoint__list__interpreter.html", "structpoint__list__interpreter" ],
    [ "si32_to_bool_list_interpreter", "structsi32__to__bool__list__interpreter.html", "structsi32__to__bool__list__interpreter" ],
    [ "size_interpreter", "structsize__interpreter.html", "structsize__interpreter" ],
    [ "size_list_interpreter", "structsize__list__interpreter.html", "structsize__list__interpreter" ],
    [ "tileparts_division_interpreter", "structtileparts__division__interpreter.html", "structtileparts__division__interpreter" ],
    [ "ui32_list_interpreter", "structui32__list__interpreter.html", "structui32__list__interpreter" ]
];

==> openjph-doc-0.25.3-1-any.pkg.tar.zst: usr/share/doc/openjph/annotated_dup.js <==
var annotated_dup =
[
    [ "ojph", "namespaceojph.html", [
      [ "net", "namespaceojph_1_1net.html", [
        [ "socket", "classojph_1_1net_1_1socket.html", "classojph_1_1net_1_1socket" ],
        [ "socket_manager", "classojph_1_1net_1_1socket__manager.html", "classojph_1_1net_1_1socket__manager" ]
      ] ],
      [ "thds", "namespaceojph_1_1thds.html", [
        [ "worker_thread_base", "classojph_1_1thds_1_1worker__thread__base.html", "classojph_1_1thds_1_1worker__thread__base" ],
        [ "thread_pool", "classojph_1_1thds_1_1thread__pool.html", "classojph_1_1thds_1_1thread__pool" ]
      ] ],
      [ "stex", "namespaceojph_1_1stex.html", [
        [ "rtp_packet", "structojph_1_1stex_1_1rtp__packet.html", "structojph_1_1stex_1_1rtp__packet" ],
        [ "packets_handler", "classojph_1_1stex_1_1packets__handler.html", "classojph_1_1stex_1_1packets__handler" ],
        [ "stex_file", "structojph_1_1stex_1_1stex__file.html", "structojph_1_1stex_1_1stex__file" ],
        [ "frames_handler", "classojph_1_1stex_1_1frames__handler.html", "classojph_1_1stex_1_1frames__handler" ],
        [ "j2k_frame_storer", "structojph_1_1stex_1_1j2k__frame__storer.html", "structojph_1_1stex_1_1j2k__frame__storer" ]
      ] ],
      [ "local", "namespaceojph_1_1local.html", [
        [ "bit_read_buf", "structojph_1_1local_1_1bit__read__buf.html", "structojph_1_1local_1_1bit__read__buf" ],
        [ "bit_write_buf", "structojph_1_1local_1_1bit__write__buf.html", "structojph_1_1local_1_1bit__write__buf" ],
        [ "codeblock", "classojph_1_1local_1_1codeblock.html", "classojph_1_1local_1_1codeblock" ],
        [ "coded_cb_header", "structojph_1_1local_1_1coded__cb__header.html", "structojph_1_1local_1_1coded__cb__header" ],
        [ "codeblock_fun", "structojph_1_1local_1_1codeblock__fun.html", "structojph_1_1local_1_1codeblock__fun" ],
        [ "codestream", "classojph_1_1local_1_1codestream.html", "classojph_1_1local_1_1codestream" ],
        [ "sqrt_energy_gains", "classojph_1_1local_1_1sqrt__energy__gains.html", "classojph_1_1local_1_1sqrt__energy__gains" ],
        [ "bibo_gains", "classojph_1_1local_1_1bibo__gains.html", "classojph_1_1local_1_1bibo__gains" ],
        [ "siz_comp_info", "structojph_1_1local_1_1siz__comp__info.html", "structojph_1_1local_1_1siz__comp__info" ],
        [ "param_siz", "structojph_1_1local_1_1param__siz.html", "structojph_1_1local_1_1param__siz" ],
        [ "cod_SPcod", "structojph_1_1local_1_1cod__SPcod.html", "structojph_1_1local_1_1cod__SPcod" ],
        [ "cod_SGcod", "structojph_1_1local_1_1cod__SGcod.html", "structojph_1_1local_1_1cod__SGcod" ],
        [ "param_cod", "structojph_1_1local_1_1param__cod.html", "structojph_1_1local_1_1param__cod" ],
        [ "param_qcd", "structojph_1_1local_1_1param__qcd.html", "structojph_1_1local_1_1param__qcd" ],
        [ "param_nlt", "structojph_1_1local_1_1param__nlt.html", "structojph_1_1local_1_1param__nlt" ],
        [ "param_cap", "structojph_1_1local_1_1param__cap.html", "structojph_1_1local_1_1param__cap" ],
        [ "param_sot", "structojph_1_1local_1_1param__sot.html", "structojph_1_1local_1_1param__sot" ],
        [ "param_tlm", "structojph_1_1local_1_1param__tlm.html", "structojph_1_1local_1_1param__tlm" ],
        [ "param_dfs", "structojph_1_1local_1_1param__dfs.html", "structojph_1_1local_1_1param__dfs" ],
        [ "lifting_step", "unionojph_1_1local_1_1lifting__step.html", "unionojph_1_1local_1_1lifting__step" ],
        [ "param_atk", "structojph_1_1local_1_1param__atk.html", "structojph_1_1local_1_1param__atk" ],
        [ "tag_tree", "structojph_1_1local_1_1tag__tree.html", "structojph_1_1local_1_1tag__tree" ],
        [ "precinct", "structojph_1_1local_1_1precinct.html", "structojph_1_1local_1_1precinct" ],
        [ "resolution", "classojph_1_1local_1_1resolution.html", "classojph_1_1local_1_1resolution" ],
        [ "subband", "classojph_1_1local_1_1subband.html", "classojph_1_1local_1_1subband" ],
        [ "tile", "classojph_1_1local_1_1tile.html", "classojph_1_1local_1_1tile" ],
        [ "tile_comp", "classojph_1_1local_1_1tile__comp.html", "classojph_1_1local_1_1tile__comp" ],
        [ "dec_mel_st", "structojph_1_1local_1_1dec__mel__st.html", "structojph_1_1local_1_1dec__mel__st" ],
        [ "rev_struct", "structojph_1_1local_1_1rev__struct.html", "structojph_1_1local_1_1rev__struct" ],
        [ "frwd_struct32", "structojph_1_1local_1_1frwd__struct32.html", "structojph_1_1local_1_1frwd__struct32" ],
        [ "frwd_struct64", "structojph_1_1local_1_1frwd__struct64.html", "structojph_1_1local_1_1frwd__struct64" ],
        [ "frwd_struct", "structojph_1_1local_1_1frwd__struct.html", "structojph_1_1local_1_1frwd__struct" ],
        [ "uvlc_tbl_struct", "structojph_1_1local_1_1uvlc__tbl__struct.html", "structojph_1_1local_1_1uvlc__tbl__struct" ],
        [ "mel_struct", "structojph_1_1local_1_1mel__struct.html", "structojph_1_1local_1_1mel__struct" ],
        [ "vlc_struct", "structojph_1_1local_1_1vlc__struct.html", "structojph_1_1local_1_1vlc__struct" ],
        [ "ms_struct", "structojph_1_1local_1_1ms__struct.html", "structojph_1_1local_1_1ms__struct" ],
        [ "CT_CNST", "structojph_1_1local_1_1CT__CNST.html", "structojph_1_1local_1_1CT__CNST" ]
      ] ],
      [ "image_in_base", "classojph_1_1image__in__base.html", "classojph_1_1image__in__base" ],
      [ "ppm_in", "classojph_1_1ppm__in.html", "classojph_1_1ppm__in" ],
      [ "dpx_in", "classojph_1_1dpx__in.html", "classojph_1_1dpx__in" ],
      [ "yuv_in", "classojph_1_1yuv__in.html", "classojph_1_1yuv__in" ],
      [ "raw_in", "classojph_1_1raw__in.html", "classojph_1_1raw__in" ],
      [ "pfm_in", "classojph_1_1pfm__in.html", "classojph_1_1pfm__in" ],
      [ "image_out_base", "classojph_1_1image__out__base.html", "classojph_1_1image__out__base" ],
      [ "ppm_out", "classojph_1_1ppm__out.html", "classojph_1_1ppm__out" ],
      [ "yuv_out", "classojph_1_1yuv__out.html", "classojph_1_1yuv__out" ],
      [ "raw_out", "classojph_1_1raw__out.html", "classojph_1_1raw__out" ],
      [ "pfm_out", "classojph_1_1pfm__out.html", "classojph_1_1pfm__out" ],
      [ "argument", "classojph_1_1argument.html", "classojph_1_1argument" ],
      [ "cli_interpreter", "classojph_1_1cli__interpreter.html", "classojph_1_1cli__interpreter" ],
      [ "size", "structojph_1_1size.html", "structojph_1_1size" ],
      [ "point", "structojph_1_1point.html", "structojph_1_1point" ],
      [ "rect", "structojph_1_1rect.html", "structojph_1_1rect" ],
      [ "codestream", "classojph_1_1codestream.html", "classojph_1_1codestream" ],
      [ "outfile_base", "classojph_1_1outfile__base.html", "classojph_1_1outfile__base" ],
      [ "j2c_outfile", "classojph_1_1j2c__outfile.html", "classojph_1_1j2c__outfile" ],
      [ "mem_outfile", "classojph_1_1mem__outfile.html", "classojph_1_1mem__outfile" ],
      [ "infile_base", "classojph_1_1infile__base.html", "classojph_1_1infile__base" ],
      [ "j2c_infile", "classojph_1_1j2c__infile.html", "classojph_1_1j2c__infile" ],
      [ "mem_infile", "classojph_1_1mem__infile.html", "classojph_1_1mem__infile" ],
      [ "mem_fixed_allocator", "classojph_1_1mem__fixed__allocator.html", "classojph_1_1mem__fixed__allocator" ],
      [ "line_buf", "classojph_1_1line__buf.html", "classojph_1_1line__buf" ],
      [ "lifting_buf", "structojph_1_1lifting__buf.html", "structojph_1_1lifting__buf" ],
      [ "coded_lists", "structojph_1_1coded__lists.html", "structojph_1_1coded__lists" ],
      [ "mem_elastic_allocator", "classojph_1_1mem__elastic__allocator.html", "classojph_1_1mem__elastic__allocator" ],
      [ "message_base", "classojph_1_1message__base.html", "classojph_1_1message__base" ],
      [ "message_info", "classojph_1_1message__info.html", "classojph_1_1message__info" ],
      [ "message_warning", "classojph_1_1message__warning.html", "classojph_1_1message__warning" ],
      [ "message_error", "classojph_1_1message__error.html", "classojph_1_1message__error" ],
      [ "param_siz", "classojph_1_1param__siz.html", "classojph_1_1param__siz" ],
      [ "param_cod", "classojph_1_1param__cod.html", "classojph_1_1param__cod" ],
      [ "param_coc", "classojph_1_1param__coc.html", "classojph_1_1param__coc" ],
      [ "param_qcd", "classojph_1_1param__qcd.html", "classojph_1_1param__qcd" ],
      [ "param_nlt", "classojph_1_1param__nlt.html", "classojph_1_1param__nlt" ],
      [ "comment_exchange", "classojph_1_1comment__exchange.html", "classojph_1_1comment__exchange" ]
    ] ],
    [ "img_info", "structimg__info.html", "structimg__info" ],
    [ "j2k_struct", "structj2k__struct.html", "structj2k__struct" ],
    [ "point_interpreter", "structpoint__interpreter.html", "structpoint__interpreter" ],
    [ "point_list_interpreter", "structpoint__list__interpreter.html", "structpoint__list__interpreter" ],
    [ "si32_to_bool_list_interpreter", "structsi32__to__bool__list__interpreter.html", "structsi32__to__bool__list__interpreter" ],
    [ "size_interpreter", "structsize__interpreter.html", "structsize__interpreter" ],
    [ "size_list_interpreter", "structsize__list__interpreter.html", "structsize__list__interpreter" ],
    [ "tileparts_division_interpreter", "structtileparts__division__interpreter.html", "structtileparts__division__interpreter" ],
    [ "ui32_list_interpreter", "structui32__list__interpreter.html", "structui32__list__interpreter" ]
];
